==> banshee-1-0.99.1.tar.bz2: banshee-1-0.99.1/src/Core/Banshee.Services/Banshee.Collection/TrackListModel.cs <==
//
// TrackListModel.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

using Hyena.Data;
using Hyena.Collections;
using Hyena.Query;

using Banshee.ServiceStack;

namespace Banshee.Collection
{
    public abstract class TrackListModel : BansheeListModel<TrackInfo>
    {
        public TrackListModel() : base ()
        {
            selection = new Selection ();
        }
        
        public TrackListModel(IDBusExportable parent) : base(parent)
        {
            selection = new Selection ();
        }
        
        public virtual int IndexOf(TrackInfo track)
        {
            throw new NotImplementedException();
        }

        public abstract TrackInfo GetRandom (DateTime notPlayedSince, bool repeat);
        
        public virtual IEnumerable<ArtistInfo> ArtistInfoFilter {
            set { throw new NotImplementedException(); }
        }
        
        public virtual IEnumerable<AlbumInfo> AlbumInfoFilter {
            set { throw new NotImplementedException(); }
        }

        public virtual void ClearArtistAlbumFilters ()
        {
        }
    }
}

==> banshee-1-1.5.1.tar.bz2: banshee-1-1.5.1/src/Core/Banshee.Services/Banshee.Collection/TrackListModel.cs <==
//
// TrackListModel.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

using Hyena.Data;
using Hyena.Collections;
using Hyena.Query;

using Banshee.ServiceStack;

namespace Banshee.Collection
{
    public abstract class TrackListModel : BansheeListModel<TrackInfo>
    {
        public TrackListModel() : base ()
        {
            selection = new Selection ();
        }
        
        public TrackListModel(IDBusExportable parent) : base(parent)
        {
            selection = new Selection ();
        }
        
        public abstract int IndexOf (TrackInfo track);

        public abstract TrackInfo GetRandom (DateTime notPlayedSince, Banshee.PlaybackController.PlaybackShuffleMode mode, bool repeat, bool lastWasSkipped);
    }
}
